@@ -16,7 +16,7 @@ class StaticFile:
         headers = {}
         path = os.path.relpath(filename, os.getcwd())
         
-        with open(path, "rb") as f:
+        with open(f"{self.directory}/{path}", "rb") as f:
             data = f.read()
         
         mimetype = mimetypes.guess_type(filename)
@@ -27,6 +27,6 @@ class StaticFile:
             }
         )
         
-        return Response(data, media_type=mimetype)
+        return Response(data, media_type=mimetype[0])
 
 
